@@ -67,17 +67,17 @@ def importResource(resourceName, resourceModuleName=None) :
         try :
             module = __import__(resourceModuleName)
         except :
-            log(importResource, f'Not possible to import {resourceName} resource. Going for a second attempt')
+            log.warning(importResource, f'Not possible to import "{resourceName}" resource from "{resourceModuleName}" module. Going for a second attempt')
             try :
                 module = importlib.import_module(resourceModuleName)
             except :
                 module = None
-                log(importResource, f'Not possible to import {resourceName} resource in the second attempt either')
+                log.warning(importResource, f'Not possible to import "{resourceName}" resource from "{resourceModuleName}" module in the second attempt either')
         if module :
             try :
                 resource = getattr(module, resourceName)
             except Exception as exception :
-                log.warning(importResource, f'Not possible to import {resourceName} from {resourceModuleName}. cause: {str(exception)}')
+                log.warning(importResource, f'Not possible to import "{resourceName}" resource from "{resourceModuleName}" module. cause: {str(exception)}')
             return resource
 
 @Function
